# MDANSE_GUI 

## MDANSE_GUI Python Module

This is the module containing the Graphical User Interface (GUI) of the
Molecular Dynamics Analysis for Neutron Scattering Experiments (MDANSE) software package.

The GUI depends on the [MDANSE package](https://www.isis.stfc.ac.uk/Pages/MDANSEproject.aspx).

## Version information

This is the beta release of MDANSE_GUI 0.1.0. Since the 1.5.x MDANSE versions,
the GUI has been re-written completely using Qt.
Please help us develop MDANSE_GUI by reporting any problems you experience when using the code.
The preferred way of reporting problems is by adding them to the [GitHub issue tracker](https://github.com/ISISNeutronMuon/MDANSE/issues).

## Quick start: installation

We recommend that you install MDANSE in a Python virtual environment. You can create a virtual environment named mdanse_env by typing
```
python3 -m venv mdanse_env
```

To activate your virtual environment, type
```
source mdanse_env/bin/activate
```
in a bash console, or
```
mdanse_end/Scripts/activate.bat
```
if you are using cmd.exe on Windows.

While your virtual environment is active, you can install MDANSE:
```
pip install MDANSE_GUI
```
and start the GUI by typing
```
mdanse_gui
```

If you experience problems with the installation, you may want to upgrade pip
```
pip install --upgrade pip
```
and try again.

## Quick start: workflow

The typical workflow of MDANSE:

1. Convert a trajectory from the file format generated by an MD simulation software into the MDANSE trajectory format,
2. Load the converted trajectory into MDANSE,
3. Perform an analysis,
4. Check the results with the plotter.

Each one of these operations (apart from the plotter) has its own dedicated tab in the GUI. The plotter can be started
using a button on the top toolbar.

The most complete user documentation of MDANSE can be found on [our Read the Docs page](https://mdanse.readthedocs.io/en/protos).

Other information including example scripts can be found on the [MDANSE website](https://www.isis.stfc.ac.uk/Pages/MDANSEproject.aspx) 

## Citing MDANSE

If you used MDANSE in your research, please cite the following paper:

>MDANSE: An Interactive Analysis Environment for Molecular Dynamics Simulations.
G. Goret, B. Aoun, E. Pellegrini. J Chem Inf Model. (2017) 57(1):1-5.

## License

MDANSE_GUI is licensed under GPL-3.0. See [LICENSE](https://github.com/ISISNeutronMuon/MDANSE/blob/develop/LICENSE) for more 
information.


## Acknowledgements

The VTK-based 3D viewer and the matplotlib-based data plotter were both taken and adapted from
other software projects authored by Eric Pellegrini. We would like to thank Eric for making
his code available.

## Joining the project

MDANSE_GUI is currently maintained and developed by software developers from ISIS and ILL, but we are fully open to new
collaborators who would like to contribute code, documentation, tutorials or usage examples.
If you want to join the project contact:

>Dr. Sanghamitra Mukhopadhyay (sanghamitra.mukhopadhyay@stfc.ac.uk) \
ISIS Neutron and Muon Source \
Rutherford Appleton Laboratory \
Didcot, UK

## Software Inquiries

You are welcome to use the
[issue tracker](https://github.com/ISISNeutronMuon/MDANSE/issues)
to submit ideas for
extending the MDANSE code or to report problems you encountered.
However, if you prefer to contact the MDANSE developers directly,
you can send us a message:
>MDANSE Help (MDANSE-help@stfc.ac.uk)
